# Contributing

## What you can do

### Add translations

To help with translations check [transifex](https://www.transifex.com/rare-1/rare)

### Add Stylesheets

For this you can create a .qss file in rare/resources/stylesheets directory or modify the existing RareStyle.qss file. Here are some
examples:
[Qt Docs](https://doc.qt.io/qt-5/stylesheet-examples.html)

### Add features

Select one Card of the project and implement it, or if you want to add another feature ask me on Discord, or create an
issue on GitHub

## Git crash-course

To contribute fork the repository and clone **your** repo: `git clone https://github.com/YourName/Rare` Then make your changes, add changed files to git with `git add File.xy rare/other_file.py`
and upload it to GitHub with `git commit -m "message"` and `git push`. Some IDEs like PyCharm can do this automatically.

If you uploaded your changes, create a pull request

# Code Style Guidelines

## Signals and threads

## Function naming

## UI Classes

### Widget and Layout naming